@@ -2,6 +2,8 @@ from .loader import DatasetLoader
 from .llm import BaseLLM
 from rich.progress import track
 from . import console
+import json
+import time
 from pathlib import Path
 from typing import Dict
 from .download import download_dataset
@@ -17,8 +19,6 @@ def evaluate_model(
         infer_kwargs: Dict = {}
     ):
 
-
-
     # sample loader
     console.log(f'will write samples to {output_dir}')
     if not output_dir.exists():
@@ -56,6 +56,7 @@ def evaluate_model(
         console.log(f'eval {sample.sample_id}...')
 
         img = sample.get_image()
+        time_start = time.time()
 
         output = llm.infer(
             img,
@@ -66,8 +67,15 @@ def evaluate_model(
             # decoding_method='Nucleus sampling'
             **infer_kwargs
         )
+        time_total = time.time() - time_start
 
-        output = f'## true class {sample.source_class}' + '\n\n' + output
+        metadata_obj = {
+            'sample_id': sample.sample_id,
+            'source_class': sample.source_class,
+            'elapsed_sec': time_total
+        }
+
+        output = f'## {json.dumps(metadata_obj)}' + '\n\n' + output
 
         console.log(output)
         
